@@ -3,13 +3,13 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0502';
+our $VERSION = '0.0600';
 
 use strict;
 use warnings;
 
 use File::ShareDir qw(dist_dir);
-use List::Util qw(any);
+use List::Util qw(any zip);
 use Music::Note;
 use Text::CSV_XS ();
 use Moo;
@@ -132,6 +132,37 @@ sub voicings {
     return $voicings;
 }
 
+
+sub fingering {
+    my ($self, $target, $chord_name, $variation) = @_;
+
+    $target = Music::Note->new($target, 'ISO')->format('midinum');
+
+    $chord_name //= '';
+
+    my @fingering;
+
+    if (defined $variation) {
+        my $fingering = $self->chords->{ 'C' . $chord_name }{fingering}[$variation];
+
+        my $pitches = $self->chords->{ 'C' . $chord_name }{notes}[$variation];
+        my $diff = $target - _lowest_c($pitches);
+
+        my ($str, $pos) = split /-/, $fingering;
+        push @fingering, $str . '-' . ($pos + $diff);
+    }
+    else {
+        for (zip $self->chords->{ 'C' . $chord_name }{notes}, $self->chords->{ 'C' . $chord_name }{fingering}) {
+            my ($pitches, $fingering) = @$_;
+            my $diff = $target - _lowest_c($pitches);
+            my ($str, $pos) = split /-/, $fingering;
+            push @fingering, $str . '-' . ($pos + $diff);
+        }
+    }
+
+    return \@fingering;
+}
+
 1;
 
 __END__
@@ -146,7 +177,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0502
+version 0.0600
 
 =head1 SYNOPSIS
 
@@ -252,6 +283,14 @@ B<voicing_file> attribute:
 Check out the link in the L</"SEE ALSO"> section for the chord shapes
 used to create this.
 
+=head2 fingering
+
+  $fingering = $mcg->fingering($target, $chord_name, $variation);
+  $fingerings = $mcg->fingering($target, $chord_name);
+
+As with the C<transform> method, but for neck position, finger
+placement.
+
 =head1 SEE ALSO
 
 The F<t/01-methods.t> and F<eg/*> files in this distribution
